@@ -136,8 +136,7 @@ void EtcTable::load() {
 EtcStartWithTable::EtcStartWithTable(const std::string& name, int size, const std::string& dir) :
     EtcTable(name, size, dir) {}
 
-EtcKeyTable::EtcKeyTable(const std::string& name, int size, const std::string& dir) :
-    EtcTable(name, size, dir) {}
+EtcKeyTable::EtcKeyTable(const std::string& name, int size, const std::string& dir) : EtcTable(name, size, dir) {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
