@@ -103,6 +103,11 @@ bool BasePathNameT<T>::available() const {
     return path_.available();
 }
 
+template <class T>
+bool BasePathNameT<T>::offsite() const {
+    return path_.offsite();
+}
+
 template <class T>
 std::string BasePathNameT<T>::clusterName() const {
     return path_.clusterName();
