@@ -35,6 +35,7 @@ class DataHandle;
 class URI {
 
 public:  // methods
+
     friend Stream& operator<<(Stream& s, const URI& uri) {
         uri.encode(s);
         return s;
@@ -43,7 +44,7 @@ public:  // methods
 
     // Contructors
     URI();
-    URI(const std::string& uri);
+    explicit URI(const std::string& uri);
     URI(const std::string& scheme, const PathName& path);
     URI(const std::string& scheme, const URI& uri);
     URI(const std::string& scheme, const std::string& hostname, int port);
@@ -89,26 +90,31 @@ public:  // methods
     std::string asRawString() const;
 
     bool operator!=(const URI& other) const {
-        return scheme_ != other.scheme_ || name_ != other.name_ || user_ != other.user_ || host_ != other.host_ || port_ != other.port_ || queryValues_ != other.queryValues_ || fragment_ != other.fragment_;
+        return scheme_ != other.scheme_ || name_ != other.name_ || user_ != other.user_ || host_ != other.host_ ||
+               port_ != other.port_ || queryValues_ != other.queryValues_ || fragment_ != other.fragment_;
     }
 
     bool operator==(const URI& other) const {
-        return scheme_ == other.scheme_ && name_ == other.name_ && user_ == other.user_ && host_ == other.host_ && port_ == other.port_ && queryValues_ == other.queryValues_ && fragment_ == other.fragment_;
+        return scheme_ == other.scheme_ && name_ == other.name_ && user_ == other.user_ && host_ == other.host_ &&
+               port_ == other.port_ && queryValues_ == other.queryValues_ && fragment_ == other.fragment_;
     }
 
 protected:  // methods
+
     void print(std::ostream&) const;
     void encode(Stream& s) const;
 
 private:  // methods
+
     size_t parseScheme(const std::string& uri);
     void parse(const std::string& uri, size_t first, bool authority, bool query, bool fragment);
     void parseQueryValues(const std::string& query);
 
-    static std::string encode(const std::string &value);
-    static std::string decode(const std::string &value);
+    static std::string encode(const std::string& value);
+    static std::string decode(const std::string& value);
 
 private:  // members
+
     std::string name_;
     std::string scheme_;
     std::string user_;
