@@ -8,37 +8,62 @@
  * does it submit to any jurisdiction.
  */
 
+#include "eckit/io/PooledFile.h"
+
 #include <cstdio>
+#include <map>
 #include <memory>
+#include <mutex>
+#include <sstream>
 #include <string>
-#include <thread>
+#include <utility>
 
 #include "eckit/config/LibEcKit.h"
 #include "eckit/config/Resource.h"
 #include "eckit/exception/Exceptions.h"
 #include "eckit/filesystem/PathName.h"
 #include "eckit/io/Buffer.h"
-#include "eckit/io/PooledFile.h"
 #include "eckit/log/Bytes.h"
 
+namespace eckit {
+class PoolFileEntry;
+}
+
+namespace {
+
+class Pool {
+
+private:
+
+    Pool() {}
+    std::map<eckit::PathName, std::unique_ptr<eckit::PoolFileEntry>> filePool_;
+    std::mutex filePoolMutex_;
+
+public:
+
+    static Pool& instance() {
+        static Pool pool;
+        return pool;
+    }
+    eckit::PoolFileEntry* get(const eckit::PathName& name);
+    void erase(const eckit::PathName& name);
+};
+
+}  // namespace
 
 namespace eckit {
 
-class PoolFileEntry;
-
-static thread_local std::map<PathName, std::unique_ptr<PoolFileEntry>> pool_;
-
 struct PoolFileEntryStatus {
 
     off_t position_;
     bool opened_;
 
-    PoolFileEntryStatus() :
-        position_(0), opened_(false) {}
+    PoolFileEntryStatus() : position_(0), opened_(false) {}
 };
 
 class PoolFileEntry {
 public:
+
     std::string name_;
     FILE* file_;
     size_t count_;
@@ -52,8 +77,8 @@ public:
     size_t nbSeeks_ = 0;
 
 public:
-    PoolFileEntry(const std::string& name) :
-        name_(name), file_(nullptr), count_(0) {}
+
+    PoolFileEntry(const std::string& name) : name_(name), file_(nullptr), count_(0) {}
 
     void doClose() {
         if (file_) {
@@ -73,12 +98,12 @@ public:
 
     void remove(const PooledFile* file) {
         auto s = statuses_.find(file);
-        if (s != statuses_.end()) {
-            statuses_.erase(s);
-        }
+        ASSERT(s != statuses_.end());
+
+        statuses_.erase(s);
         if (statuses_.size() == 0) {
             doClose();
-            pool_.erase(name_);
+            Pool::instance().erase(name_);
             // No code after !!!
         }
     }
@@ -97,7 +122,8 @@ public:
 
             Log::debug<LibEcKit>() << "PooledFile::openForRead " << name_ << std::endl;
 
-            static size_t bufferSize = Resource<size_t>("FileHandleIOBufferSize;$FILEHANDLE_IO_BUFFERSIZE;-FileHandleIOBufferSize", 0);
+            static size_t bufferSize =
+                Resource<size_t>("FileHandleIOBufferSize;$FILEHANDLE_IO_BUFFERSIZE;-FileHandleIOBufferSize", 0);
 
             if (bufferSize) {
                 Log::debug<LibEcKit>() << "PooledFile using " << Bytes(bufferSize) << std::endl;
@@ -113,10 +139,10 @@ public:
 
     void close(const PooledFile* file) {
         auto s = statuses_.find(file);
-        if (s != statuses_.end()) {
-            ASSERT(s->second.opened_);
-            s->second.opened_ = false;
-        }
+        ASSERT(s != statuses_.end());
+
+        ASSERT(s->second.opened_);
+        s->second.opened_ = false;
     }
 
     int fileno(const PooledFile* file) const {
@@ -192,15 +218,8 @@ public:
 };
 
 
-PooledFile::PooledFile(const PathName& name) :
-    name_(name), entry_(nullptr) {
-    auto j = pool_.find(name);
-    if (j == pool_.end()) {
-        pool_.emplace(std::make_pair(name, std::unique_ptr<PoolFileEntry>(new PoolFileEntry(name))));
-        j = pool_.find(name);
-    }
+PooledFile::PooledFile(const PathName& name) : name_(name), entry_(Pool::instance().get(name)) {
 
-    entry_ = (*j).second.get();
     entry_->add(this);
 }
 
@@ -262,3 +281,21 @@ PooledFileError::PooledFileError(const std::string& file, const std::string& msg
     FileError(msg + " : error on pooled file " + file, loc) {}
 
 }  // namespace eckit
+
+namespace {
+
+eckit::PoolFileEntry* Pool::get(const eckit::PathName& name) {
+    std::lock_guard<std::mutex> lock(filePoolMutex_);
+    auto j = filePool_.find(name);
+    if (j == filePool_.end()) {
+        filePool_.emplace(name, new eckit::PoolFileEntry(name));
+        j = filePool_.find(name);
+    }
+    return (*j).second.get();
+}
+void Pool::erase(const eckit::PathName& name) {
+    std::lock_guard<std::mutex> lock(filePoolMutex_);
+    filePool_.erase(name);
+}
+
+}  // namespace
\ No newline at end of file
