@@ -8,6 +8,10 @@
  * does it submit to any jurisdiction.
  */
 
+// Disable warnings: warning #550-D: variable "__d0" was set but never used [set_but_not_used] in FD_ZERO(&r);
+#if defined(__NVCOMPILER)
+#pragma diag_suppress 550
+#endif
 
 #include <sys/ioctl.h>
 #include <unistd.h>
@@ -21,19 +25,16 @@ namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-Select::Select() :
-    last_(-1) {
+Select::Select() : last_(-1) {
     FD_ZERO(&files_);
 }
 
-Select::Select(net::TCPSocket& p) :
-    last_(-1) {
+Select::Select(net::TCPSocket& p) : last_(-1) {
     FD_ZERO(&files_);
     add(p);
 }
 
-Select::Select(int fd) :
-    last_(-1) {
+Select::Select(int fd) : last_(-1) {
     FD_ZERO(&files_);
     add(fd);
 }
