@@ -16,6 +16,9 @@
 
 #include "eckit/memory/NonCopyable.h"
 
+#include <set>
+#include <string>
+
 namespace eckit {
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -25,12 +28,14 @@ class NodeInfo;
 
 class ClusterNode : private eckit::NonCopyable {
 public:
+
     ClusterNode();
 
     virtual ~ClusterNode();
 
     void heartbeat();
 
+    virtual const std::set<std::string>& attributes() const;
     virtual int port() const         = 0;
     virtual void initialise(Stream&) = 0;
     virtual void refresh(Stream&)    = 0;
