@@ -13,16 +13,11 @@
 
 #include "eckit/linalg/LinearAlgebraDense.h"
 
-
-namespace eckit {
-namespace linalg {
-namespace dense {
-
+namespace eckit::linalg::dense {
 
 struct LinearAlgebraGeneric final : public LinearAlgebraDense {
     LinearAlgebraGeneric() {}
-    LinearAlgebraGeneric(const std::string& name) :
-        LinearAlgebraDense(name) {}
+    LinearAlgebraGeneric(const std::string& name) : LinearAlgebraDense(name) {}
 
     Scalar dot(const Vector&, const Vector&) const override;
     void gemv(const Matrix&, const Vector&, Vector&) const override;
@@ -30,7 +25,4 @@ struct LinearAlgebraGeneric final : public LinearAlgebraDense {
     void print(std::ostream&) const override;
 };
 
-
-}  // namespace dense
-}  // namespace linalg
-}  // namespace eckit
+}  // namespace eckit::linalg::dense
