@@ -8,6 +8,8 @@
  * does it submit to any jurisdiction.
  */
 
+#include <cstdint>
+#include <iomanip>
 #include <sstream>
 
 #include "eckit/eckit.h"
@@ -20,13 +22,17 @@ namespace eckit {
 
 const char* TimeStamp::defaultFormat_ = "%Y-%m-%d %H:%M:%S";
 
-TimeStamp::TimeStamp(const std::string& format) :
-    time_(Clock::now()), format_(format) {}
+TimeStamp::TimeStamp(const std::string& format) : time_(Clock::now()), format_(format) {}
 
-TimeStamp::TimeStamp(time_t t, const std::string& format) :
-    time_(t), format_(format) {}
+TimeStamp::TimeStamp(time_t t, const std::string& format) : time_(t), format_(format) {}
 
 std::ostream& operator<<(std::ostream& s, const TimeStamp& x) {
+
+    if (x.format_ == "hex") {
+        s << std::setw(16) << std::setfill('0') << std::hex << static_cast<std::uint64_t>(x.time_);
+        return s;
+    }
+
     char buf[80];
 #if eckit_HAVE_GMTIME_R
     struct tm t;
