@@ -28,17 +28,20 @@ class Parallel;
 class ParallelRequest : public RequestContent {
 
 private:  // constructor
+
     ParallelRequest();
     ParallelRequest(MPI_Request);
 
 private:  // methods
-    virtual void print(std::ostream&) const override;
 
-    virtual int request() const override;
+    void print(std::ostream&) const override;
 
-    virtual bool test() override;
+    int request() const override;
+
+    bool test() override;
 
 private:  // members
+
     friend class Parallel;
 
     MPI_Request request_;
