@@ -13,13 +13,11 @@
 #include "eckit/mpi/Serial.h"
 #include "eckit/mpi/SerialStatus.h"
 
-namespace eckit {
-namespace mpi {
+namespace eckit::mpi {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-SerialStatus::SerialStatus() :
-    source_(Serial::Constants::anySource()), tag_(Serial::Constants::anyTag()), error_(0) {}
+SerialStatus::SerialStatus() : source_(Serial::Constants::anySource()), tag_(Serial::Constants::anyTag()), error_(0) {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -30,5 +28,4 @@ void SerialStatus::print(std::ostream& os) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace mpi
-}  // namespace eckit
+}  // namespace eckit::mpi
