@@ -37,8 +37,7 @@ bool HttpHeader::compare::operator()(const std::string& a, const std::string& b)
 }
 
 
-HttpHeader::HttpHeader() :
-    version_("HTTP/1.0"), statusCode_(HttpError::OK), contentLength_(0), received_(false) {
+HttpHeader::HttpHeader() : version_("HTTP/1.0"), statusCode_(HttpError::OK), contentLength_(0), received_(false) {
     header_[Content_Type]    = "text/html";
     header_["Cache-Control"] = "no-cache";
     header_["MIME-Version"]  = "1.0";
@@ -46,15 +45,18 @@ HttpHeader::HttpHeader() :
 
 HttpHeader& HttpHeader::operator=(std::map<std::string, std::string, std::less<std::string> >& parsed) {
     for (std::map<std::string, std::string, std::less<std::string> >::const_iterator i = parsed.begin();
-         i != parsed.end(); ++i)
+         i != parsed.end(); ++i) {
         header_[(*i).first] = (*i).second;
+    }
 
     Map::const_iterator j = header_.find(Content_Length);
 
-    if (j != header_.end())
+    if (j != header_.end()) {
         contentLength_ = atol(((*j).second).c_str());
-    else
+    }
+    else {
         contentLength_ = 0;
+    }
 
     return *this;
 }
@@ -132,8 +134,9 @@ void HttpHeader::print(std::ostream& s) const {
 
     long len      = content_.size();
     const char* p = static_cast<const char*>(content_.data());
-    while (len-- > 0)
+    while (len-- > 0) {
         s.put(*p++);
+    }
 }
 
 void HttpHeader::forward(const std::string& s) {
@@ -163,8 +166,9 @@ void HttpHeader::type(const std::string& s) {
 const std::string& HttpHeader::type() const {
     Map::const_iterator i = header_.find(Content_Type);
 
-    if (i != header_.end())
+    if (i != header_.end()) {
         return (*i).second;
+    }
 
     return DefaultType;
 }
@@ -187,21 +191,27 @@ bool HttpHeader::authenticated() const {
     if (i != header_.end()) {
         const char* s = (*i).second.c_str();
 
-        while (*s != ' ' && *s != '\t')
+        while (*s != ' ' && *s != '\t') {
             s++;
-        while (*s == ' ' || *s == '\t')
+        }
+        while (*s == ' ' || *s == '\t') {
             s++;
+        }
 
         unsigned char b64[256];
-        for (int j = 0; j < 256; j++)
+        for (int j = 0; j < 256; j++) {
             b64[j] = 64;
+        }
 
-        for (unsigned char c = 'A'; c <= 'Z'; c++)
+        for (unsigned char c = 'A'; c <= 'Z'; c++) {
             b64[c] = c - 'A';
-        for (unsigned char c = 'a'; c <= 'z'; c++)
+        }
+        for (unsigned char c = 'a'; c <= 'z'; c++) {
             b64[c] = c - 'a' + 26;
-        for (unsigned char c = '0'; c <= '9'; c++)
+        }
+        for (unsigned char c = '0'; c <= '9'; c++) {
             b64[c] = c - '0' + 52;
+        }
 
         b64[int('+')] = 62;
         b64[int('/')] = 63;
@@ -276,8 +286,7 @@ static std::string nextLine(net::TCPSocket& socket) {
     }
 }
 
-HttpHeader::HttpHeader(net::TCPSocket& socket) :
-    received_(true) {
+HttpHeader::HttpHeader(net::TCPSocket& socket) : received_(true) {
     std::string line = nextLine(socket);
 
     size_t i = line.find_first_of(' ');
