@@ -23,17 +23,20 @@ namespace net {
 
 class NetUser : public Thread {
 public:
+
     NetUser(net::TCPSocket&);
 
     ~NetUser();
 
 protected:
+
     TCPSocket protocol_;
 
 private:
+
     virtual void serve(Stream&, std::istream&, std::ostream&) = 0;
 
-    virtual void run();
+    void run() override;
 
     friend class NetServiceProcessControler;
 };
