@@ -17,18 +17,19 @@
 
 #include "eckit/sql/SQLOutput.h"
 
-namespace eckit {
-namespace sql {
+namespace eckit::sql {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class SQLSimpleOutput : public SQLOutput {
 
 public:  // methods
+
     SQLSimpleOutput(const SQLOutputConfig& config, std::ostream& out);
-    virtual ~SQLSimpleOutput() override;
+    ~SQLSimpleOutput() override;
 
 private:  // methods
+
     template <typename T>
     void outputValue(double x, bool missing);
 
@@ -37,24 +38,26 @@ private:  // methods
     void printHeader(SQLSelect&);
 
 private:  // methods (overrides)
-    virtual void print(std::ostream&) const override;
 
-    virtual void reset() override;
-    virtual void flush() override;
-    virtual bool output(const expression::Expressions&) override;
-    virtual void prepare(SQLSelect&) override;
-    virtual void updateTypes(SQLSelect&) override;
-    virtual void cleanup(SQLSelect&) override;
-    virtual unsigned long long count() override;
+    void print(std::ostream&) const override;
 
-    virtual void outputReal(double, bool) override;
-    virtual void outputDouble(double, bool) override;
-    virtual void outputInt(double, bool) override;
-    virtual void outputUnsignedInt(double, bool) override;
-    virtual void outputString(const char*, size_t, bool) override;
-    virtual void outputBitfield(double, bool) override;
+    void reset() override;
+    void flush() override;
+    bool output(const expression::Expressions&) override;
+    void prepare(SQLSelect&) override;
+    void updateTypes(SQLSelect&) override;
+    void cleanup(SQLSelect&) override;
+    unsigned long long count() override;
+
+    void outputReal(double, bool) override;
+    void outputDouble(double, bool) override;
+    void outputInt(double, bool) override;
+    void outputUnsignedInt(double, bool) override;
+    void outputString(const char*, size_t, bool) override;
+    void outputBitfield(double, bool) override;
 
 private:  // members
+
     std::ostream& out_;
     unsigned long long count_;
     std::vector<size_t> columnWidths_;
@@ -67,7 +70,6 @@ private:  // members
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql
 
 #endif
