@@ -12,28 +12,23 @@
 
 using namespace eckit;
 
-namespace eckit {
-namespace sql {
+namespace eckit::sql {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 ColumnDef::ColumnDef(const std::string& name, const std::string& type, const BitfieldDef& bitfield) :
     //                     const Range &range,
     //                     const std::string& defaultValue) {}
-    name_(name),
-    type_(type),
-    bitfield_(bitfield) {}
+    name_(name), type_(type), bitfield_(bitfield) {}
 
 ColumnDef::ColumnDef() {}
 
 ColumnDef::~ColumnDef() {}
 
-TableDef::TableDef(const std::string& name, const ColumnDefs& columns) :
-    name_(name), columns_(columns) {}
+TableDef::TableDef(const std::string& name, const ColumnDefs& columns) : name_(name), columns_(columns) {}
 
 TableDef::~TableDef() {}
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql
