@@ -22,12 +22,13 @@ class Buffer;
 class SnappyCompressor : public eckit::Compressor {
 
 public:  // methods
+
     SnappyCompressor();
 
-    virtual ~SnappyCompressor() override;
+    ~SnappyCompressor() override;
 
-    virtual size_t compress(const void* in, size_t len, eckit::Buffer& out) const override;
-    virtual void uncompress(const void* in, size_t len, eckit::Buffer& out, size_t outlen) const override;
+    size_t compress(const void* in, size_t len, eckit::Buffer& out) const override;
+    void uncompress(const void* in, size_t len, eckit::Buffer& out, size_t outlen) const override;
 
 protected:  // methods
 };
