@@ -3,15 +3,15 @@
 */
 
 #include <arpa/inet.h>
-#include <cerrno>
 #include <netdb.h>
 #include <netinet/in.h>
-#include <cstdio>
-#include <cstdlib>
-#include <cstring>
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <cerrno>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 
 #include "eckit/eckit.h"
 
@@ -30,21 +30,23 @@ namespace eckit {
 
 class SysLogServer : public Application {
 public:
+
     SysLogServer(int argc, char** argv);
     ~SysLogServer();
 
 private:
+
     SysLogServer(const SysLogServer&);
     SysLogServer& operator=(const SysLogServer&);
 
     virtual void run();
 
 private:  // members
+
     eckit::net::Port port_;
 };
 
-SysLogServer::SysLogServer(int argc, char** argv) :
-    Application(argc, argv), port_("syslog", 6512) {}
+SysLogServer::SysLogServer(int argc, char** argv) : Application(argc, argv), port_("syslog", 6512) {}
 
 SysLogServer::~SysLogServer() {}
 
