@@ -36,15 +36,18 @@ static const std::vector<std::string> STRING_DATA{
     "aaaabbbb", "cccc", "dddd", "eeffg", "hijklmno", "a-string", "a-longer-string", "another-string", ""};
 static const std::vector<double> REAL_DATA2{3.0, 4.0, -12.3, 93.7, 11.11, 3.1415, -5.4321, 1.0, -2.0};
 
-static const std::vector<long> DATE_DATA{20210616, 0, 99991231, 100000000, 20210615, 20210614, 20210613, 20210612, 20210611};
+static const std::vector<long> DATE_DATA{20210616, 0,        99991231, 100000000, 20210615,
+                                         20210614, 20210613, 20210612, 20210611};
 static const std::vector<long> TIME_DATA{123456, 123456, 123456, 123456, 0, 654321, 6543, 1000000, 114335};
 
-static const std::vector<long> DATE_DATA2{20210615, 20210614, 20210613, 20210612, 20210611, 20210616, 0, 99991231, 100000000};
+static const std::vector<long> DATE_DATA2{20210615, 20210614, 20210613, 20210612, 20210611,
+                                          20210616, 0,        99991231, 100000000};
 static const std::vector<long> TIME_DATA2{0, 654321, 6543, 1000000, 114335, 123456, 123456, 123456, 123456};
 
 class TestTable : public eckit::sql::SQLTable {
 
 public:
+
     TestTable(eckit::sql::SQLDatabase& db, const std::string& path, const std::string& name) :
         SQLTable(db, path, name) {
         addColumn("icol", 0, eckit::sql::type::SQLType::lookup("integer"), false, 0);
@@ -58,8 +61,10 @@ public:
     }
 
 private:
+
     class TestTableIterator : public eckit::sql::SQLTableIterator {
     public:
+
         TestTableIterator(const TestTable& owner,
                           const std::vector<std::reference_wrapper<const eckit::sql::SQLColumn>>& columns) :
             /* owner_(owner), */ idx_(0), data_(9) {
@@ -74,6 +79,7 @@ private:
         }
 
     private:
+
         ~TestTableIterator() override {}
         void rewind() override { idx_ = 0; }
         bool next() override {
@@ -153,6 +159,7 @@ class TestOutput : public eckit::sql::SQLOutput {
     };
 
 public:  // visible members
+
     std::vector<long> intOutput;
     std::vector<double> floatOutput;
     std::vector<std::string> strOutput;
@@ -333,7 +340,8 @@ CASE("Functions using test data") {
 
     SECTION("Test simple arithmetic -- addition/subtraction") {
 
-        std::string sql = "select icol + 15.3, rcol + 13.5, icol + rcol, icol - 15.3, rcol - 13.5, icol - rcol from table1";
+        std::string sql =
+            "select icol + 15.3, rcol + 13.5, icol + rcol, icol - 15.3, rcol - 13.5, icol - rcol from table1";
         eckit::sql::SQLParser().parseString(session, sql);
 
         session.statement().execute();
@@ -349,60 +357,11 @@ CASE("Functions using test data") {
         //    print ", ".join("{:7.1f}".format(v) for v in (ii+15.3, rr+13.5, ii+rr, ii-15.3, rr-13.5, ii-rr))
 
         std::vector<double> expected{
-            10014.3,
-            113.4,
-            10098.9,
-            9983.7,
-            86.4,
-            9899.1,
-            8903.3,
-            102.3,
-            8976.8,
-            8872.7,
-            75.3,
-            8799.2,
-            7792.3,
-            91.2,
-            7854.7,
-            7761.7,
-            64.2,
-            7699.3,
-            6681.3,
-            80.1,
-            6732.6,
-            6650.7,
-            53.1,
-            6599.4,
-            5570.3,
-            69.0,
-            5610.5,
-            5539.7,
-            42.0,
-            5499.5,
-            4459.3,
-            57.9,
-            4488.4,
-            4428.7,
-            30.9,
-            4399.6,
-            3348.3,
-            46.8,
-            3366.3,
-            3317.7,
-            19.8,
-            3299.7,
-            2237.3,
-            35.7,
-            2244.2,
-            2206.7,
-            8.7,
-            2199.8,
-            1126.3,
-            24.6,
-            1122.1,
-            1095.7,
-            -2.4,
-            1099.9,
+            10014.3, 113.4,  10098.9, 9983.7, 86.4,   9899.1, 8903.3, 102.3,  8976.8, 8872.7, 75.3,
+            8799.2,  7792.3, 91.2,    7854.7, 7761.7, 64.2,   7699.3, 6681.3, 80.1,   6732.6, 6650.7,
+            53.1,    6599.4, 5570.3,  69.0,   5610.5, 5539.7, 42.0,   5499.5, 4459.3, 57.9,   4488.4,
+            4428.7,  30.9,   4399.6,  3348.3, 46.8,   3366.3, 3317.7, 19.8,   3299.7, 2237.3, 35.7,
+            2244.2,  2206.7, 8.7,     2199.8, 1126.3, 24.6,   1122.1, 1095.7, -2.4,   1099.9,
         };
 
         EXPECT(is_approximately_equal(o.floatOutput, expected, 0.000001));
@@ -410,7 +369,8 @@ CASE("Functions using test data") {
 
     SECTION("Test simple arithmetic -- multiplication/division") {
 
-        std::string sql = "select icol * 15.3, rcol * 13.5, icol * rcol, icol / 15.3, rcol / 13.5, icol / rcol from table1";
+        std::string sql =
+            "select icol * 15.3, rcol * 13.5, icol * rcol, icol / 15.3, rcol / 13.5, icol / rcol from table1";
         eckit::sql::SQLParser().parseString(session, sql);
 
         session.statement().execute();
@@ -426,13 +386,13 @@ CASE("Functions using test data") {
         //     print ", ".join("{:7.4f}".format(v) for v in (ii*15.3, rr*13.5, ii*rr, ii/15.3, rr/13.5, ii/rr))
 
         std::vector<double> expected{
-            152984.7000, 1348.6500, 998900.1000, 653.5294, 7.4000, 100.0901, 135986.4000, 1198.8000,
-            789254.4000, 580.9150, 6.5778, 100.0901, 118988.1000, 1048.9500, 604272.9000, 508.3007,
-            5.7556, 100.0901, 101989.8000, 899.1000, 443955.6000, 435.6863, 4.9333, 100.0901,
-            84991.5000, 749.2500, 308302.5000, 363.0719, 4.1111, 100.0901, 67993.2000, 599.4000,
-            197313.6000, 290.4575, 3.2889, 100.0901, 50994.9000, 449.5500, 110988.9000, 217.8431,
-            2.4667, 100.0901, 33996.6000, 299.7000, 49328.4000, 145.2288, 1.6444, 100.0901,
-            16998.3000, 149.8500, 12332.1000, 72.6144, 0.8222, 100.0901};
+            152984.7000, 1348.6500, 998900.1000, 653.5294, 7.4000,      100.0901,  135986.4000, 1198.8000,
+            789254.4000, 580.9150,  6.5778,      100.0901, 118988.1000, 1048.9500, 604272.9000, 508.3007,
+            5.7556,      100.0901,  101989.8000, 899.1000, 443955.6000, 435.6863,  4.9333,      100.0901,
+            84991.5000,  749.2500,  308302.5000, 363.0719, 4.1111,      100.0901,  67993.2000,  599.4000,
+            197313.6000, 290.4575,  3.2889,      100.0901, 50994.9000,  449.5500,  110988.9000, 217.8431,
+            2.4667,      100.0901,  33996.6000,  299.7000, 49328.4000,  145.2288,  1.6444,      100.0901,
+            16998.3000,  149.8500,  12332.1000,  72.6144,  0.8222,      100.0901};
 
         EXPECT(is_approximately_equal(o.floatOutput, expected, 0.0001));
     }
@@ -587,16 +547,8 @@ CASE("Functions using test data") {
         EXPECT(o.floatOutput.size() == 0);
         EXPECT(o.strOutput.size() == 0);
 
-        std::vector<long> expectedInt{
-            20210616123456,
-            123456,
-            99991231123456,
-            -1,
-            20210615000000,
-            -1,
-            20210613006543,
-            -1,
-            20210611114335};
+        std::vector<long> expectedInt{20210616123456, 123456, 99991231123456, -1, 20210615000000, -1,
+                                      20210613006543, -1,     20210611114335};
         EXPECT(o.intOutput == expectedInt);
     }
 
@@ -611,16 +563,7 @@ CASE("Functions using test data") {
         EXPECT(o.floatOutput.size() == 0);
         EXPECT(o.strOutput.size() == 0);
 
-        std::vector<long> expectedInt{
-            131696,
-            -1,
-            -1,
-            -1,
-            303385,
-            -1,
-            -1,
-            -1,
-            -1};
+        std::vector<long> expectedInt{131696, -1, -1, -1, 303385, -1, -1, -1, -1};
         EXPECT(o.intOutput == expectedInt);
     }
 }
